@@ -2,10 +2,10 @@ from __future__ import annotations
 
 import string
 import sys
-from typing import Any, Callable, Dict, List, Union, Optional, Type, Tuple, TYPE_CHECKING
+from typing import Any, Callable, Union, Optional, Type, Tuple, TYPE_CHECKING
 
 from maybe import Maybe
-from subtypes import Enum, ValueEnum, Dict
+from subtypes import Enum, ValueEnum, Dict, DoNotTranslateMeta
 from miscutils import cached_property, is_running_in_ipython
 
 from .synchronizer import Synchronizer
@@ -18,7 +18,6 @@ if TYPE_CHECKING:
 
 # TODO: implement argument profiles
 # TODO: improve dependent arguments
-# TODO: improve smart runmode logic
 
 
 class RunMode(Enum):
@@ -34,6 +33,13 @@ class ArgType(ValueEnum):
     PATH, FILE, DIR = Validate.Path, Validate.File, Validate.Dir
 
 
+class ImplicitNone:
+    pass
+
+
+implicit_none = ImplicitNone()
+
+
 class IOHandler:
     """
     A class that handles I/O by collecting arguments through the commandline, or generates a GUI to collect arguments if no commandline arguments are provided.
@@ -86,10 +92,10 @@ class IOHandler:
         self.subcommands[name] = subcommand
         return subcommand
 
-    def process(self, values: dict = None, handler: IOHandler = None) -> CallableDict:
+    def process(self, values: Union[dict, ImplicitNone] = implicit_none, handler: IOHandler = None) -> CallableDict:
         """Collect input using this IOHandler's 'run_mode' and return a CallableDict holding the parsed arguments, coerced to appropriate python types."""
         self.sync = Synchronizer(root_handler=self)
-        namespace, handler = self._choose_handler_method()(values=values, handler=handler)
+        namespace, handler = self._delegate_to_synchronizer(values=values, handler=handler)
 
         handler._save_latest_input_config(namespace=namespace)
         return CallableDict(dictionary=namespace, callback=handler.callback)
@@ -109,22 +115,29 @@ class IOHandler:
         if outdir:
             self.outdir.clear()
 
-    def _choose_handler_method(self) -> Callable:
-        return RunMode(self.run_mode).map_to({
-            RunMode.COMMANDLINE: self.sync.run_from_commandline,
-            RunMode.GUI: self.sync.run_as_gui,
-            RunMode.PROGRAMMATIC: self.sync.run_programatically,
-            RunMode.SMART: self._run_smart
-        })
-
-    def _run_smart(self, *args: Any, **kwargs: Any) -> Tuple[Dict, IOHandler]:
-        if is_running_in_ipython():
-            return self.sync.run_programatically(*args, **kwargs)
+    def _delegate_to_synchronizer(self, values: Union[dict, ImplicitNone], handler: IOHandler) -> Tuple[Dict, IOHandler]:
+        if self.run_mode == RunMode.SMART:
+            return self._run_smart(values=values, handler=handler)
         else:
+            handler_method = RunMode(self.run_mode).map_to({
+                RunMode.COMMANDLINE: self.sync.run_from_commandline,
+                RunMode.GUI: self.sync.run_as_gui,
+                RunMode.PROGRAMMATIC: self.sync.run_programatically,
+            })
+
+            return handler_method(values=None if values is implicit_none else values, handler=handler)
+
+    def _run_smart(self, values: Union[dict, ImplicitNone], handler: IOHandler) -> Tuple[Dict, IOHandler]:
+        if values is None or is_running_in_ipython():
+            return self.sync.run_programatically(values=values, handler=handler)
+        else:
+            if values is implicit_none:
+                values = None
+
             if not sys.argv[1:]:
-                return self.sync.run_as_gui(*args, **kwargs)
+                return self.sync.run_as_gui(values=values, handler=handler)
             else:
-                return self.sync.run_from_commandline(*args, **kwargs)
+                return self.sync.run_from_commandline(values=values, handler=handler)
 
     def _save_latest_input_config(self, namespace: Dict) -> None:
         self._latest.content = namespace
@@ -252,10 +265,7 @@ class Nullability:
         return self.truth if self.argument.dependency is None else True
 
 
-class CallableDict(Dict):
-    settings = Dict.settings.deepcopy()
-    settings.recursive = False
-
+class CallableDict(Dict, metaclass=DoNotTranslateMeta):
     def __init__(self, dictionary: Dict, callback: Callable = None) -> None:
         super().__init__(dictionary)
         self._callback_ = callback
